==> rc-ui-lib-0.1.41.tgz: package/es/uploader/UploaderPreviewItem.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/* eslint-disable no-console */
import React, { useContext } from 'react';
import cls from 'classnames'; // Utils

import { isImageFile } from './utils';
import { isDef, getSizeStyle, extend } from '../utils';
import { callInterceptor } from '../utils/interceptor'; // Components

import Icon from '../icon';
import Image from '../image';
import Loading from '../loading';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
export var UploaderPreviewItem = function UploaderPreviewItem(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('uploader', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var renderMask = function renderMask() {
    var _props$item = props.item,
        status = _props$item.status,
        message = _props$item.message;

    if (status === 'uploading' || status === 'failed') {
      var MaskIcon = status === 'failed' ? /*#__PURE__*/React.createElement(Icon, {
        name: "close",
        className: cls(bem('mask-icon'))
      }) : /*#__PURE__*/React.createElement(Loading, {
        className: cls(bem('loading'))
      });
      var showMessage = isDef(message) && message !== '';
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('mask'))
      }, MaskIcon, showMessage && /*#__PURE__*/React.createElement("div", {
        className: cls(bem('mask-message'))
      }, message));
    }

    return null;
  };

  var onDelete = function onDelete(event) {
    var name = props.name,
        item = props.item,
        index = props.index,
        beforeDelete = props.beforeDelete;
    event.stopPropagation();
    callInterceptor({
      interceptor: beforeDelete,
      args: [item, {
        name: name,
        index: index
      }],
      done: function done() {
        var _props$onDelete;

        return (_props$onDelete = props.onDelete) === null || _props$onDelete === void 0 ? void 0 : _props$onDelete.call(props);
      }
    });
  };

  var onPreview = function onPreview() {
    if (props.onPreview) props.onPreview();
  };

  var renderDeleteIcon = function renderDeleteIcon() {
    if (props.deletable && props.item.status !== 'uploading') {
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('preview-delete')),
        onClick: onDelete
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "cross",
        className: cls(bem('preview-delete-icon'))
      }));
    }

    return null;
  };

  var renderCover = function renderCover() {
    if (props.previewCoverRender) {
      var index = props.index,
          item = props.item;
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('preview-cover'))
      }, props.previewCoverRender(extend({
        index: index
      }, item)));
    }

    return null;
  };

  var renderPreview = function renderPreview() {
    var item = props.item;

    if (isImageFile(item)) {
      return /*#__PURE__*/React.createElement(Image, {
        fit: props.imageFit,
        src: item.content || item.url,
        className: cls(bem('preview-image')),
        width: props.previewSize,
        height: props.previewSize,
        onClick: onPreview
      }, renderCover());
    }

    return /*#__PURE__*/React.createElement("div", {
      className: cls(bem('file')),
      style: getSizeStyle(props.previewSize)
    }, /*#__PURE__*/React.createElement(Icon, {
      className: cls(bem('file-icon')),
      name: "description"
    }), /*#__PURE__*/React.createElement("div", {
      className: cls(bem('file-name'), 'rc-ellipsis')
    }, item.file ? item.file.name : item.url), renderCover());
  };

  return /*#__PURE__*/React.createElement("div", {
    className: cls(bem('preview')),
    onClick: props.onClick
  }, renderPreview(), renderMask(), renderDeleteIcon());
};

==> rc-ui-lib-1.3.4.tgz: package/es/uploader/UploaderPreviewItem.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/* eslint-disable no-console */
import React, { useContext } from 'react';
import classnames from 'classnames'; // Utils

import { isImageFile } from './utils';
import { isDef, getSizeStyle, extend } from '../utils';
import { callInterceptor } from '../utils/interceptor'; // Components

import Icon from '../icon';
import Image from '../image';
import Loading from '../loading';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
export var UploaderPreviewItem = function UploaderPreviewItem(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('uploader', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var renderMask = function renderMask() {
    var _props$item = props.item,
        status = _props$item.status,
        message = _props$item.message;

    if (status === 'uploading' || status === 'failed') {
      var MaskIcon = status === 'failed' ? /*#__PURE__*/React.createElement(Icon, {
        name: "close",
        className: classnames(bem('mask-icon'))
      }) : /*#__PURE__*/React.createElement(Loading, {
        className: classnames(bem('loading'))
      });
      var showMessage = isDef(message) && message !== '';
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('mask'))
      }, MaskIcon, showMessage && /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('mask-message'))
      }, message));
    }

    return null;
  };

  var onDelete = function onDelete(event) {
    var name = props.name,
        item = props.item,
        index = props.index,
        beforeDelete = props.beforeDelete;
    event.stopPropagation();
    callInterceptor({
      interceptor: beforeDelete,
      args: [item, {
        name: name,
        index: index
      }],
      done: function done() {
        var _props$onDelete;

        return (_props$onDelete = props.onDelete) === null || _props$onDelete === void 0 ? void 0 : _props$onDelete.call(props);
      }
    });
  };

  var onPreview = function onPreview() {
    if (props.onPreview) props.onPreview();
  };

  var renderDeleteIcon = function renderDeleteIcon() {
    if (props.deletable && props.item.status !== 'uploading') {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('preview-delete')),
        onClick: onDelete
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "cross",
        className: classnames(bem('preview-delete-icon'))
      }));
    }

    return null;
  };

  var renderCover = function renderCover() {
    if (props.previewCoverRender) {
      var index = props.index,
          item = props.item;
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('preview-cover'))
      }, props.previewCoverRender(extend({
        index: index
      }, item)));
    }

    return null;
  };

  var renderPreview = function renderPreview() {
    var item = props.item;

    if (isImageFile(item)) {
      return /*#__PURE__*/React.createElement(Image, {
        fit: props.imageFit,
        src: item.content || item.url,
        className: classnames(bem('preview-image')),
        width: props.previewSize,
        height: props.previewSize,
        onClick: onPreview
      }, renderCover());
    }

    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('file')),
      style: getSizeStyle(props.previewSize)
    }, /*#__PURE__*/React.createElement(Icon, {
      className: classnames(bem('file-icon')),
      name: "description"
    }), /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('file-name'), 'rc-ellipsis')
    }, item.file ? item.file.name : item.url), renderCover());
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('preview')),
    onClick: props.onClick
  }, renderPreview(), renderMask(), renderDeleteIcon());
};
